@@ -90,11 +90,14 @@ class ContrastiveLearningDataset_PCL(Dataset):
         # Load TIFF file
         elif self.image_list[idx].endswith('.tif') or self.image_list[idx].endswith('.tiff'): 
             image = io.imread(self.root_folder+self.image_list[idx])                
-            image = image.swapaxes(0,2)
+            
+            if np.argmin(image.shape)==0:
+                image = image.swapaxes(0,2)                            
+            
             image = image[:,:,self.Channels]
             if self.args['PCL_Z_Score'] and hasattr(self, 'mean'):
-                image -= np.expand_dims(np.expand_dims(self.mean,0),0)
-                image /= np.expand_dims(np.expand_dims(self.std,0),0)
+                image = image-np.expand_dims(np.expand_dims(self.mean,0),0)
+                image = image/np.expand_dims(np.expand_dims(self.std,0),0)
         else:
             image =  np.load(self.root_folder+self.image_list[idx],allow_pickle=True)  
             from PIL import Image            
