@@ -422,4 +422,67 @@ def parameters(path, debug):
         # Bioinsights parameters
         args['Bio_save_Orig_im'] = False
 
+    else:
+        
+        # Patch contrastive learning parameters
+        args['PCL_CNN_Architecture']='resnet50' # or resnet18
+        args['PCL_N_Workers']=8 # Number of data loading workers 
+        args['PCL_Epochs']=80 # Number of total epoch to run
+        args['PCL_N_Crops_per_Image']=40 # Number of crops chosen per image
+        args['PCL_Patch_Size']=30 # Size of patches in pixels
+        args['PCL_Stride']=0 # Size of stride between consecutive patches
+        args['PCL_Alpha_L']=1.15 # size ratio between image crop and image patch
+        args['PCL_Z_Score']= True # Whether to apply z score per channel/marker
+        args['PCL_Batch_Size']= 1 # Number of images per iteration
+        args['PCL_Weight_Decay']= 1e-4 # Weight Decay
+        args['PCL_Out_Dimensions']= 128 # Feature dimensions of patch
+        args['PCL_Learning_Rate']= 0.003 # Learning Rate
+        args['PCL_Temperature']= 0.07 # Softmax temperature    
+        args['PCL_eliminate_Black_Background'] = False
+        args['PCL_eliminate_White_Background'] = False            
+        args['PCL_GPU_INDEX']= torch.device('cuda:0') # GPU where the training is carried out 
+
+        # Label you want to infer with respect the images.
+        args['experiment_Label'] = ['Clinical_Benefit'] 
+
+        # Architecture Search parameters
+        args['num_samples_architecture_search'] = 1500  
+
+        # Optimization Parameters
+        args['epochs'] = 1000# if debug else hp.quniform('epochs', 5, 25, 1)
+        args['lr_decay_factor'] = 0.1# if debug else hp.uniform('lr_decay_factor', 0, 0.75)
+        args['lr_decay_step_size'] = 10000#max(int(args['epochs']/5),1)# if debug else hp.quniform('lr_decay_step_size', 2, 20, 1)        
+        args['weight_decay'] = 4 if debug=='Index' else hp.choice('weight_decay',[0.1,0.01,0.001,0.0001,0]) if debug=='Object' else 0
+        args['batch_size'] = 3 if debug=='Index' else hp.choice('batch_size', [2, 4, 8, 24]) if debug=='Object' else 24
+        args['lr'] = 0 if debug=='Index' else hp.choice('lr', [1,0.1,0.01,0.001,0.0001]) if debug=='Object' else 1
+
+        # General
+        args['training_MODE'] = 'TrainALL' # TrainALL, NestedCrossValidation, CrossValidation # Whether to use nested cross validation or cross validation.        
+        args['folds'] = 1
+        args['device'] = 'cuda:0'
+        args['Batch_Normalization'] = True
+        args['dataAugmentationPerc'] = 0 #0 if debug=='Index' else hp.choice("dataAugmentationPerc", [0,0.0001,0.001]) if debug=='Object' else 0  
+
+        # Neural Network
+        args['N_Phenotypes'] = 8#2 if debug=='Index' else hp.choice('clusters1',[5,10,15,20]) if debug=='Object' else 15     
+        args['N_Neighborhoods'] = 16#1 if debug=='Index' else hp.choice('clusters2',[6,11,16,21]) if debug=='Object' else 11 
+        args['N_Areas'] = 4#0 if debug=='Index' else hp.choice('clusters3',[2,4,7]) if debug=='Object' else 2      
+        args['Phenotype_Learning'] = True  
+        args['Neighborhood_Learning'] = True
+        args['Area_Learning'] = True
+        args['dropoutRate'] = 0# 1 if debug=='Index' else hp.choice('dropoutRate', [0.1, 0.2, 0.3,0.4]) if debug=='Object' else 0.2        
+        args['attntnThreshold'] = 0# if debug=='Index' else hp.choice('attntnThreshold', [0,.2,.4,.6,.8]) if debug=='Object' else 0  
+                
+        # Losses
+        args['ContrastACC_Pheno'] = 0.01#4 if debug=='Index' else hp.choice("orthoColor_Lambda0", [1,0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                
+        args['ContrastACC_Neigh'] = 0.01#4 if debug=='Index' else hp.choice("orthoColor_Lambda1", [1, 0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                              
+        args['ContrastACC_Area'] = 0.0001#4 if debug=='Index' else hp.choice("orthoColor_Lambda1", [1, 0.1,0.01,0.001,0.0001,0.00001]) if debug=='Object' else 0.0001                                              
+        args['PatchEntropy_Pheno'] = 0.01#3 if debug=='Index' else hp.choice("min_Cell_entropy_Lambda0", [1,0.1,0.01,0.001,0]) if debug=='Object' else 0.001   
+        args['PatchEntropy_Neigh'] = 0.01#4 if debug=='Index' else hp.choice("min_Cell_entropy_Lambda1", [1,0.1,0.01,0.001,0]) if debug=='Object' else 0
+        args['PatchEntropy_Area'] = 0.0001#1 if debug=='Index' else hp.choice("min_Cell_entropy_Lambda2", [1,0.1,0.01,0.001,0]) if debug=='Object' else 0.1          
+        
+        # Bioinsights parameters
+        args['Bio_save_Orig_im'] = True
+
+
     return args
\ No newline at end of file
